self.__BUILD_MANIFEST=function(a,s,e,c,t,p,i,d,n,b,f,u){return{__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":[a,s,"static/chunks/pages/index-34f33eba8b802804.js"],"/_error":["static/chunks/pages/_error-a4ba2246ff8fb532.js"],"/app/bridges/openon":[a,s,e,c,p,i,d,"static/chunks/pages/app/bridges/openon-5f6c1fb34ffc1433.js"],"/app/bridges/setup":[a,s,e,c,p,i,n,"static/chunks/pages/app/bridges/setup-92a922cae166507f.js"],"/app/data":[a,t,s,c,"static/chunks/549-ba183b21e51f4fe4.js","static/chunks/pages/app/data-6d41f3b637a3dd46.js"],"/app/notification":[a,s,i,"static/chunks/pages/app/notification-f3b9f4f2945369b4.js"],"/app/player/audio":[a,t,b,s,e,f,u,"static/chunks/pages/app/player/audio-34441e06ed2cfabb.js"],"/app/player/video":[a,t,b,s,e,f,u,"static/chunks/pages/app/player/video-ed14ae2b78fc2ef8.js"],"/app/settings":[a,t,s,e,c,p,d,n,"static/chunks/377-9936de8ec9156df4.js","static/chunks/pages/app/settings-57dd532e31282c36.js"],sortedPages:["/","/_app","/_error","/app/bridges/openon","/app/bridges/setup","/app/data","/app/notification","/app/player/audio","/app/player/video","/app/settings"]}}("static/chunks/b2e984c5-1b480e34f3250640.js","static/chunks/413-a2215078161ea43d.js","static/chunks/311-23ef056e2b876e0b.js","static/chunks/316-837a85a587d6a5bb.js","static/chunks/29107295-fbcfe2172188e46f.js","static/chunks/699-cd2f1c65486290e7.js","static/chunks/669-e83532188aad81cf.js","static/chunks/284-07105d0bcbe400a0.js","static/chunks/767-716e9d0074432d47.js","static/chunks/75fc9c18-e61c2e0d9c9a0957.js","static/chunks/625-3bc080426f8a8c0d.js","static/chunks/173-6ba9ea9fd2a1e7dc.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();