"""
Provides systembridgefrontend version information.
"""

# This file is auto-generated! Do not edit!
# Use `python -m incremental.update systembridgefrontend` to change this file.

from incremental import Version

__version__ = Version("systembridgefrontend", 3, 4, 5, dev=2)
__all__ = ["__version__"]
