(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[405],{8312:function(e,t,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/",function(){return n(5075)}])},311:function(e,t,n){"use strict";n.d(t,{Z:function(){return P}});var i=n(6042),r=n(9396),s=n(5893),o=n(7294),a=n(1163),l=n(9008),c=n.n(l),d=n(3946),u=n(8849),h=n(3648),p=n(8298),m=n(2734),x=n(2293),f=n(3156),y=n(155),v=n(6886),g=n(3321),j=n(5861),w=n(7357);function Z(e){var t=e.children,n=(0,p.Z)({disableHysteresis:!0,threshold:24});return(0,o.cloneElement)(t,{elevation:n?4:0})}var _=function(){var e=(0,o.useState)(!1),t=e[0],n=e[1],i=((0,o.useCallback)((function(){n(!t)}),[t]),(0,m.Z)());return(0,s.jsx)(s.Fragment,{children:(0,s.jsx)(Z,{children:(0,s.jsxs)(s.Fragment,{children:[(0,s.jsx)(x.Z,{color:"transparent",elevation:0,children:(0,s.jsx)(f.Z,{maxWidth:"xl",sx:{padding:0},children:(0,s.jsx)(y.Z,{sx:{minHeight:50,maxHeight:50,padding:0,flex:1,alignItems:"center",justifyContent:"space-between",display:"flex",flexWrap:"nowrap"},children:(0,s.jsx)(v.ZP,{item:!0,children:(0,s.jsx)(g.Z,{href:"https://system-bridge.timmo.dev",target:"_blank",children:(0,s.jsx)(j.Z,{component:"div",variant:"h4",sx:{textTransform:"none",userSelect:"none",color:i.palette.primary.contrastText},children:"System Bridge"})})})})})}),(0,s.jsx)(w.Z,{sx:{height:i.spacing(18)}})]})})})},k=!1;var P=function(e){var t=(0,a.useRouter)();return(0,o.useEffect)((function(){if(t.isReady&&!k){var e,n,s,o;k=!0;var a=(null===(e=t.query)||void 0===e?void 0:e.apiKey)||"",l=(null===(n=t.query)||void 0===n?void 0:n.apiPort)||"9170",c=!1;if((null===(s=t.query)||void 0===s?void 0:s.apiKey)||(c=!0,a=window.prompt("Please enter your API key",a)),(null===(o=t.query)||void 0===o?void 0:o.apiPort)||(c=!0,l=window.prompt("Please enter your API port (default: 9170)",l)),c&&a&&l){var d=t.asPath.split("?")[0];t.replace({pathname:d.includes(".html")?d:"".concat(d,".html"),query:(0,r.Z)((0,i.Z)({},t.query),{apiKey:a,apiPort:l})})}}}),[t]),(0,s.jsxs)(s.Fragment,{children:[(0,s.jsxs)(c(),{children:[(0,s.jsx)("title",{children:e.title?"".concat(e.title," - System Bridge"):"System Bridge"}),(0,s.jsx)("link",{rel:"canonical",href:e.url}),(0,s.jsx)("meta",{name:"description",content:e.description?"".concat(e.description):e.title?"".concat(e.title," - System Bridge"):"System Bridge"}),(0,s.jsx)("meta",{name:"keywords",content:e.keywords?"".concat(e.keywords):"system-bridge, system, bridge, typescript"})]}),!e.noHeader&&(0,s.jsx)(_,{}),e.closeButton&&(0,s.jsx)(d.Z,{size:"small",sx:{position:"absolute",top:4,right:4,zIndex:1e3},onClick:function(){window.location.href="http://close.window"},children:(0,s.jsx)(u.Icon,{id:"close",path:h.r5M,size:1})}),e.children]})}},5075:function(e,t,n){"use strict";n.r(t);var i=n(5893),r=(n(7294),n(3156)),s=n(311);t.default=function(){return(0,i.jsx)(s.Z,{title:"Placeholder",url:"https://system-bridge.timmo.dev",description:"Frontend for System Bridge",children:(0,i.jsx)(r.Z,{component:"article",maxWidth:"xl",children:(0,i.jsx)(i.Fragment,{})})})}}},function(e){e.O(0,[702,413,774,888,179],(function(){return t=8312,e(e.s=t);var t}));var t=e.O();_N_E=t}]);