@font-face{font-family:Roboto;font-style:normal;font-display:swap;font-weight:400;src:url(/_next/static/media/roboto-cyrillic-ext-400-normal.d7827ae3.woff2) format("woff2"),url(/_next/static/media/roboto-all-400-normal.2e9e9400.woff) format("woff");unicode-range:U+0460-052f,U+1c80-1c88,U+20b4,U+2de0-2dff,U+a640-a69f,U+fe2e-fe2f}@font-face{font-family:Roboto;font-style:normal;font-display:swap;font-weight:400;src:url(/_next/static/media/roboto-cyrillic-400-normal.2d9c9d60.woff2) format("woff2"),url(/_next/static/media/roboto-all-400-normal.2e9e9400.woff) format("woff");unicode-range:U+0400-045f,U+0490-0491,U+04b0-04b1,U+2116}@font-face{font-family:Roboto;font-style:normal;font-display:swap;font-weight:400;src:url(/_next/static/media/roboto-greek-ext-400-normal.2b547ded.woff2) format("woff2"),url(/_next/static/media/roboto-all-400-normal.2e9e9400.woff) format("woff");unicode-range:U+1f??}@font-face{font-family:Roboto;font-style:normal;font-display:swap;font-weight:400;src:url(/_next/static/media/roboto-greek-400-normal.63e6dc18.woff2) format("woff2"),url(/_next/static/media/roboto-all-400-normal.2e9e9400.woff) format("woff");unicode-range:U+0370-03ff}@font-face{font-family:Roboto;font-style:normal;font-display:swap;font-weight:400;src:url(/_next/static/media/roboto-vietnamese-400-normal.c95fc061.woff2) format("woff2"),url(/_next/static/media/roboto-all-400-normal.2e9e9400.woff) format("woff");unicode-range:U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01a0-01a1,U+01af-01b0,U+1ea0-1ef9,U+20ab}@font-face{font-family:Roboto;font-style:normal;font-display:swap;font-weight:400;src:url(/_next/static/media/roboto-latin-ext-400-normal.21abc8c8.woff2) format("woff2"),url(/_next/static/media/roboto-all-400-normal.2e9e9400.woff) format("woff");unicode-range:U+0100-024f,U+0259,U+1e??,U+2020,U+20a0-20ab,U+20ad-20cf,U+2113,U+2c60-2c7f,U+a720-a7ff}@font-face{font-family:Roboto;font-style:normal;font-display:swap;font-weight:400;src:url(/_next/static/media/roboto-latin-400-normal.f2894edc.woff2) format("woff2"),url(/_next/static/media/roboto-all-400-normal.2e9e9400.woff) format("woff");unicode-range:U+00??,U+0131,U+0152-0153,U+02bb-02bc,U+02c6,U+02da,U+02dc,U+2000-206f,U+2074,U+20ac,U+2122,U+2191,U+2193,U+2212,U+2215,U+feff,U+fffd}#__next,body,html{min-height:100%;height:100%}a{color:#009688;text-decoration:none}img{max-width:100%}