(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[998],{3049:function(e,n,r){(window.__NEXT_P=window.__NEXT_P||[]).push(["/app/player/video",function(){return r(9043)}])},9043:function(e,n,r){"use strict";r.r(n);var t=r(5893),i=(r(7294),r(3564)),o=r(311),u=r(7902);n.default=function(){return(0,t.jsx)(o.Z,{title:"Video Player",url:"https://system-bridge.timmo.dev",description:"Frontend for System Bridge",closeButton:!0,noHeader:!0,children:(0,t.jsx)(i.I0,{children:(0,t.jsx)(u.Z,{playerType:"video"})})})}}},function(e){e.O(0,[702,662,885,413,311,625,173,774,888,179],(function(){return n=3049,e(e.s=n);var n}));var n=e.O();_N_E=n}]);